/**
  *  \file client/cscreen.h
  *  \brief Control Screens
  *
  *  (c) 2001-2017 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_CLIENT_CSCREEN_H
#define PCC_V2_CLIENT_CSCREEN_H

#include "client/chart.h"
#include "game/objtypes.h"
#include "ui/ui.h"
#include "cpluslib/holder.h"
#include "client/wtile.h"
#include "client/screens.h"
#include "client/widgets/scanresult.h"
#include "int/keymap.h"
#include "int/if/userif.h"
#include "client/tiles.h"
#include "cpluslib/ptrmultilist.h"
#include "client/dialogbinding.h"

class WControlScreen;
class WScannerChartWidget;

class WControlScreen : public UIFixedWidget, public IntUserInterfaceDialogBinding, public WTileContainer {
 protected:
    ObjectHolder holder;

 private:
    class Skin;

    /* Identification */
    WScreenId::ScreenId  screen_id;            ///< Screen Id (function key number).
    IntKeymapRef         keymap;               ///< Keymap.
    GObjectSelection&    selection;            ///< Object selection.
    SignalConnection     conn_pos_changed;     ///< Connection to type's sig_pos_changed.

    /* Widgets */
    WScanResult          scanner;              ///< Scanner widget.
    WScannerChartWidget* chart;                ///< Starchart widget.
    SignalConnection     conn_chart_dblclick;  ///< Starchart double-clicked.

    /* Tile positioning */
    int                  tile_width;           ///< Width of one column.
    int                  tile_y;               ///< Current Y.
    int                  tile_x;               ///< Current X.
    int                  tile_new_y;           ///< Y for new columns.
    int                  chart_y2;             ///< Bottom Y of starchart widget. Top Y is derived from our top.
    int                  chart_x1;             ///< Left X of starchart widget. Right X is derived from our right X.

    void setGeometry();
    void onCurrentChanged();
    void onChartDblclick();

 protected:
    void addChart(WScannerChartWidget& chart);
    void setKeymap(IntKeymapRef keymap);

 public:
    WControlScreen(GObjectSelection& selection, WScreenId::ScreenId screen_id);
    ~WControlScreen();

    void          drawContent(GfxCanvas& can);
    bool          handleEvent(const UIEvent& e, bool second_pass);

    void          doBrowse(bool forward, bool marked);

    GObjectSelection& getObjectSelection();
    GPoint        getScannerPosition() const;
    WScanResult&  getScanner();
    WScreenId::ScreenId getScreenId() const;

    virtual void  update() = 0;

    void          runScreen();

    // IntUserInterfaceChildBinding:
    virtual IntValue* getProperty(IntUserInterfaceProperty p);
    virtual void setProperty(IntUserInterfaceProperty p, IntValue* v);

    // IntUserInterfaceDialogBinding:
    virtual bool processPreIdle();
    virtual bool processEvent(std::auto_ptr<IntUserInterfaceEvent> event);

    // WTileContainer
    void          addNewTile(WTile* t);
};

/** Get contained object selection. */
inline GObjectSelection&
WControlScreen::getObjectSelection()
{
    return selection;
}

/** Get contained scanner view. */
inline WScanResult&
WControlScreen::getScanner()
{
    return scanner;
}

/** Get screen Id. */
inline WScreenId::ScreenId
WControlScreen::getScreenId() const
{
    return screen_id;
}

#endif
