/**
  *  \file client/dialogs/tagselect.cc
  *  \brief Select a Marker Tag
  *
  *  (c) 2001-2017 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "client/dialogs/tagselect.h"
#include "game/drawing.h"
#include "game/global.h"
#include "ui/listbox.h"
#include "ui/uiglobal.h"
#include "util/misc.h"
#include "util/nls.h"
#include "util/strlist.h"

/** Build list of tags.
    \param list [out] Output
    \param add [in] If nonzero, tag to additionally include in the list */
void
buildCurrentTagList(StringList& list, atom_t add)
{
    // Enumerate list of tags
    GDrawingAtomMap map;
    getDisplayedTurn().getCurrentUniverse().getDrawings().computeAtomMap(map, GDrawingContainer::IncludeNumeric);

    if (add) {
        map.add(add);
    }

    // Generate list for display
    // Note that this must not use numToString() because we're possibly going to parse these numbers!
    for (GDrawingAtomMap::iterator it = map.begin(), e = map.end(); it != e; ++it) {
        list.add(*it, isAtom(*it) ? atomStr(*it) : itoa(*it));
    }
    list.sortAlphabetically();
}


/** Select marker tag.
    \param out [in/out] Current selection
    \retval true User confirmed; %out has been updated
    \retval false User canceled */
bool
selectMarkerTag(atom_t& out)
{
    // Must have turn
    if (!haveDisplayedTurn()) {
        return false;
    }

    // Build the list
    StringList list;
    buildCurrentTagList(list, 0);
    if (list.getCount() == 0) {
        return false;
    }

    // Build dialog and pick one
    UIStandardListbox box(0, 20, 30 * font_ems[FONT_NORMAL], list);
    box.scrollToKey(out);
    if (box.doStandardListbox(_("Filter Drawings"), "pcc2:drawtag")) {
        out = box.getKey();
        return true;
    } else {
        return false;
    }
}
