/**
  *  \file game/cargotype.h
  *  \brief Cargo Types
  *
  *  (c) 2001-2017 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_GAME_CARGOTYPE_H
#define PCC_V2_GAME_CARGOTYPE_H

#include "cpluslib/assert.h"
#include "cpluslib/smallset.h"
#include "cpluslib/string.h"
#include "game/struct.h"

/** Cargo type. */
enum GCargoType {
    el_Neutronium,              ///< Neutronium.
    el_Tritanium,               ///< Tritanium.
    el_Duranium,                ///< Duranium.
    el_Molybdenum,              ///< Molybdenum.
    el_Fighters,                ///< Fighters.
    el_Colonists,               ///< Colonist clans.
    el_Supplies,                ///< Supplies.
    el_Money,                   ///< Cash.
    el_Torps,                   ///< Torps. \see getTorpTypeFromCargoType(), getCargoTypeFromTorpType()
    el_COUNT = el_Torps + NUM_TORPS,
    el_FIRST = el_Neutronium
};

typedef SmallSet<GCargoType> GCargoTypeSet;

/* bummer. Why can't C++ have these built-in? */
inline GCargoType operator++(GCargoType& t) { return t = GCargoType(t+1); }
inline GCargoType operator--(GCargoType& t) { return t = GCargoType(t-1); }
inline GCargoType operator++(GCargoType& t,int) { GCargoType rv = t; ++t; return rv; }
inline GCargoType operator--(GCargoType& t,int) { GCargoType rv = t; --t; return rv; }

/** Get torpedo type number from cargo type. */
inline int
getTorpTypeFromCargoType(GCargoType type)
{
    ASSERT(type >= el_Torps && type < el_Torps + NUM_TORPS);
    return type - el_Torps + 1;
}

/** Check whether cargo type corresponds to a torpedo type. */
inline int
isCargoTorpedo(GCargoType type)
{
    return type >= el_Torps && type < el_Torps + NUM_TORPS;
}

/** Get cargo type from torpedo type.
    \param type torpedo type, [1,NUM_TORPS] */
inline GCargoType
getCargoTypeFromTorpType(int type)
{
    ASSERT(type > 0 && type <= NUM_TORPS);
    return GCargoType(el_Torps + type - 1);
}

string_t getCargoName(GCargoType type);
string_t getCargoUnit(GCargoType type);

#endif
