/**
  *  \file ui/panel.cc
  *  \brief Panel widget
  *
  *  (c) 2001-2017 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "ui/panel.h"
#include "ui/skin.h"
#include "ui/uiglobal.h"
#include "gfx/palette.h"
#include "ui/layout.h"
#include "ui/util.h"

static UISkin panel_skin_instance(DARK_COLOR_SET);

/******************************** UIPanel ********************************/

/** Constructor.
    \param space Pixels to reserve (and not to give to sub-layout) at borders */
UIPanel::UIPanel(int space)
    : UILayoutableWidget(UINullLayout::instance),
      space(space)
{
    setSkin(panel_skin_instance);
}

UIPanel::~UIPanel()
{ }

void
UIPanel::drawContent(GfxCanvas& can)
{
    GfxRect r = getExtent();
    drawFrameUp(can, r);
    r.grow(-1, -1);
    drawSolidBar(can, r, standard_colors[panel_skin_instance.getColors()[UIColor::tc_Background]]);
    can.update(getExtent());
}

void
UIPanel::adjustSize(GfxRect& size, bool to_inner)
{
    if (to_inner)
        size.grow(-space, -space);
    else
        size.grow(space, space);
}
