/**
  *  \file util/strtab.cc
  *  \brief String Tables
  *
  *  (c) 2001-2017 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "util/strtab.h"
#include "util/nls.h"

/****************************** StringTable ******************************/

int
StringTable::getFirstIndex() const
{
    return 0;
}

int
StringTable::getNextIndex(int n) const
{
    return n+1;
}

/*************************** StaticStringTable ***************************/

/** Construct from array.
    \param table Array
    \param count Number of elements in array */
StaticStringTable::StaticStringTable(const char*const* table, std::size_t count)
    : table(table), count(count)
{ }

/** Construct from NULL-terminated array.
    \param table Array */
StaticStringTable::StaticStringTable(const char*const* table)
    : table(table), count(0)
{
    while (table[count] != 0)
        ++count;
}

string_t
StaticStringTable::get(int index) const
{
    if (index >= 0 && index < count && table[index] != 0)
        return table[index];
    else
        return "???";
}

int
StaticStringTable::getLastIndex() const
{
    return count;
}

/********************** StaticTranslatedStringTable **********************/

string_t
StaticTranslatedStringTable::get(int index) const
{
    return _(StaticStringTable::get(index).c_str());
}
